package eu.mhsl.minenet.minigames;

import eu.mhsl.minenet.minigames.command.Commands;
import eu.mhsl.minenet.minigames.handler.Listeners;
import eu.mhsl.minenet.minigames.lang.Languages;
import eu.mhsl.minenet.minigames.server.tasks.TablistUpdateTask;
import eu.mhsl.minenet.minigames.server.provider.ByPlayerNameUuidProvider;
import io.github.bloepiloepi.pvp.PvpExtension;
import net.minestom.server.MinecraftServer;
import net.minestom.server.extras.lan.OpenToLAN;
import net.minestom.server.timer.TaskSchedule;

import java.util.logging.Logger;

public class Main {
    /**
     * Starts minenet minigames services
     * @param args startflags
     */
    private final static Logger logger = Logger.getGlobal();
    public static void main(String[] args) {

        logger.info("Initialize Minecraft server...");
        MinecraftServer server = MinecraftServer.init();
        PvpExtension.init();

        MinecraftServer.setBrandName("minenet");
        MinecraftServer.setCompressionThreshold(0);
        System.setProperty("minestom.chunk-view-distance", "12");

        MinecraftServer.getConnectionManager().setUuidProvider(new ByPlayerNameUuidProvider());

        Commands.values();
        Listeners.values();

        MinecraftServer.getSchedulerManager().scheduleTask(new TablistUpdateTask(), TaskSchedule.tick(20), TaskSchedule.tick(20));

        //noinspection ResultOfMethodCallIgnored
        Resource.values(); // This initializes and preloads the enum and extracts the resources
        Languages.getInstance(); //Preload languages into the jvm

        logger.info("Starting Minecraft server ... ");
        OpenToLAN.open();
        //MojangAuth.init(); LET NON MIGRATORS PLAY!
        server.start("0.0.0.0", 25565);
        System.gc();

        MinecraftServer.getSchedulerManager().scheduleNextTick(() -> logger.info("Minecraft server is now running!"));
    }
}
